import { resolve } from 'path'
import { fileURLToPath, URL } from 'node:url'

import vue from '@vitejs/plugin-vue2'
import mkcert from 'vite-plugin-mkcert'
import cssInjectedByJsPlugin from 'vite-plugin-css-injected-by-js'
import { ElementUiResolver } from 'unplugin-vue-components/resolvers'
import Components from 'unplugin-vue-components/vite'

export default {
  plugins: [
    vue(),
    Components({
      resolvers: [ElementUiResolver()],
    }),
    cssInjectedByJsPlugin(),
    mkcert(),
  ],
  server: {
    open: true,
    host: 'dev.ezijing.com',
    proxy: {
      '/api': 'https://project-api.ezijing.com',
    },
  },
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url)),
    },
  },
  build: {
    lib: {
      entry: resolve(import.meta.dirname, 'src/index.js'),
      name: 'VueForm',
      fileName: 'vue-form',
    },
    rollupOptions: {
      external: ['vue', 'axios'],
      output: { globals: { vue: 'Vue', axios: 'axios' } },
    },
  },
}
